@@ -336,7 +336,7 @@ class SSCursorTestCase(unittest.TestCase):
     def assertList(self, iterable):
         self.assertEqual(
             [x.data for x in iterable],
-            map(str, range(1, self.counter + 1)))
+            [str(i) for i in range(1, self.counter + 1)])
 
     def test_model_interaction(self):
         query = SSCursorModel.select().order_by(SSCursorModel.data)
@@ -362,16 +362,15 @@ class SSCursorTestCase(unittest.TestCase):
 
         # After the transaction we cannot fetch a result because the cursor
         # is dead.
-        with self.assertRaises(psycopg2.ProgrammingError):
-            qr2.cursor.fetchone()
+        self.assertRaises(psycopg2.ProgrammingError, qr2.cursor.fetchone)
 
         # Try using the helper.
         query4 = query.clone()
         self.assertList(ServerSide(query4))
 
         # Named cursor is dead.
-        with self.assertRaises(psycopg2.ProgrammingError):
-            query4._qr.cursor.fetchone()
+        self.assertRaises(
+            psycopg2.ProgrammingError, query4._qr.cursor.fetchone)
 
     def test_serverside_normal_model(self):
         query = NormalModel.select().order_by(NormalModel.data)
@@ -384,8 +383,7 @@ class SSCursorTestCase(unittest.TestCase):
         self.assertList(ServerSide(clone))
 
         # Named cursor is dead.
-        with self.assertRaises(psycopg2.ProgrammingError):
-            clone._qr.cursor.fetchone()
+        self.assertRaises(psycopg2.ProgrammingError, clone._qr.cursor.fetchone)
 
         # Ensure where clause is preserved.
         query = query.where(NormalModel.data == '2')
@@ -411,15 +409,20 @@ class SSCursorTestCase(unittest.TestCase):
 
         # Explicitly close the cursor.
         test_ss_db.commit()
-        with self.assertRaises(psycopg2.ProgrammingError):
-            cursor.fetchone()
+        self.assertRaises(psycopg2.ProgrammingError, cursor.fetchone)
 
         # This would not work is the named cursor was still holding a ref to
         # the table.
         test_ss_db.execute_sql('truncate table %s;' % tbl)
         test_ss_db.commit()
 
-if TestingJson is not None:
+def json_ok():
+    if TestingJson is None:
+        return False
+    conn = test_db.get_conn()
+    return conn.server_version >= 90300
+
+if json_ok():
     from psycopg2.extras import Json
 
     class TestJsonField(unittest.TestCase):
@@ -457,6 +460,5 @@ if TestingJson is not None:
 
             self.assertItems((TestingJson.data['k2']['xxx'] == 'v1'))
 
-
 elif TEST_VERBOSITY > 0:
     print_('Skipping postgres "Json" tests, unsupported version.')
